@@ -95,9 +95,9 @@ def rm_server_redis(clean=False):
     pass
 
 
-def server_mongo():
+def server_mongo(card='lo'):
     """
-    @note, by default, mongodb bind 0.0.0.0 and we don't plan change it
+    @note, by default, mongodb bind 0.0.0.0, so we bind
     only support 64-bit system
     :return:
     """
@@ -114,7 +114,15 @@ def server_mongo():
     put(fh.name, '/etc/yum.repos.d/mongodb.repo')
     os.remove(fh.name)
 
+
     run('yum install mongodb-org -y')
+
+
+    if card:
+        ip = cmd_ip(card)
+        run('sed -i -e "s/\(bind_ip\s*=\s*\)[0-9\.]*/\\1%s/g" /etc/mongodb.conf' % ip)
+
+
     run('chkconfig --level 35 mongod on')
     pass
 
